@@ -1,9 +1,8 @@
-# Tai Sakuma <tai.sakuma@gmail.com>
 import sys
 
-from .detect.jupy import is_jupyter_notebook
-
 from .bartty import ProgressBar
+from .base import Presentation
+from .detect.jupy import is_jupyter_notebook
 from .txtprint import ProgressPrint
 
 try:
@@ -11,9 +10,9 @@ try:
 except ImportError:
     pass
 
-##__________________________________________________________________||
-def create_presentation():
-    """Create a presentation of progress report, e.g., progress bars
+
+def create_presentation() -> Presentation:
+    '''Create a presentation of progress report, e.g., progress bars
 
     Returns
     -------
@@ -22,7 +21,7 @@ def create_presentation():
         an instance of ProgressBarJupyter if on Jupyter Notebook
         an instance of ProgressPrint otherwise
 
-    """
+    '''
 
     if sys.stdout.isatty():
         return ProgressBar()
@@ -34,5 +33,3 @@ def create_presentation():
             pass
 
     return ProgressPrint()
-
-##__________________________________________________________________||
