@@ -1,5 +1,3 @@
-
-##__________________________________________________________________||
 try:
     import ipywidgets as widgets
 except ImportError:
@@ -8,26 +6,26 @@ except ImportError:
 try:
     from IPython.display import display
 except ImportError:
-    display = None
+    display = None  # type: ignore
 
 try:
     from IPython import get_ipython
 except ImportError:
-    get_ipython = None
+    get_ipython = None  # type: ignore
 
 
 from .spy import is_spyder_ide
 
-##__________________________________________________________________||
-def is_jupyter_notebook():
-    """Tests if on Jupyter Notebook
+
+def is_jupyter_notebook() -> bool:
+    '''Tests if on Jupyter Notebook
 
     Returns
     -------
     bool
         True if on Jupyter Notebook
 
-    """
+    '''
 
     if widgets is None:
         return False
@@ -45,5 +43,3 @@ def is_jupyter_notebook():
         return False
 
     return True
-
-##__________________________________________________________________||
